@@ -2,7 +2,7 @@
 #
 #  Test of CRC generator.
 #
-#   Copyright (C) 2020-2021 Michael Buesch <m@bues.ch>
+#   Copyright (C) 2020-2022 Michael Buesch <m@bues.ch>
 #
 #  Some CRC implementations are derived from AVR-libc.
 #  These copyright notices apply to the AVR-libc parts:
@@ -43,6 +43,7 @@
 #
 
 from libcrcgen import *
+from libcrcgen.generator_test import *
 from libcrcgen.reference import *
 from libcrcgen.util import *
 import multiprocessing
@@ -267,11 +268,11 @@ def compareGeneratedImpl(optimize, alg, crcParameters, quick):
 	else:
 		dataBitsRange = (8, 16, 24, 32, 33, 1)
 	for nrDataBits in dataBitsRange:
-		gen = CrcGen(P=crcParameters["polynomial"],
-			     nrCrcBits=crcParameters["nrBits"],
-			     nrDataBits=nrDataBits,
-			     shiftRight=crcParameters["shiftRight"],
-			     optimize=optimize)
+		gen = CrcGenTest(P=crcParameters["polynomial"],
+				 nrCrcBits=crcParameters["nrBits"],
+				 nrDataBits=nrDataBits,
+				 shiftRight=crcParameters["shiftRight"],
+				 optimize=optimize)
 		gen.runTests(name=alg, extra=("-O=%d" % optimize))
 
 if __name__ == "__main__":
@@ -309,6 +310,15 @@ if __name__ == "__main__":
 			(0x07,
 			 "x^8 + x^2 + x + 1",
 			 8, False),
+			(0x03,
+			 "x^3 + x + 1",
+			 3, False),
+			(0x01,
+			 "x^3 + 1",
+			 3, False),
+			(0x02,
+			 "x^3 + x",
+			 3, False),
 		):
 		print("Testing %s..." % polyString)
 		if poly2int(polyString, nrBits, shiftRight) != poly:
