@@ -1,6 +1,6 @@
 from pyprofibus.conf import PbConf, PbConfError
 from pyprofibus.dp import DpError
-from pyprofibus.dp_master import DPM1, DPM2, DpSlaveDesc
+from pyprofibus.dp_master import DPM1, DPM2
 from pyprofibus.fdl import FdlError
 from pyprofibus.phy import PhyError
 from pyprofibus.util import ProfibusError
